@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::Role::WithOverloading::Meta::Role::Composite::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $MooseX::Role::WithOverloading::Meta::Role::Composite::VERSION = '0.07';
+  $MooseX::Role::WithOverloading::Meta::Role::Composite::VERSION = '0.08';
 }
 # ABSTRACT: Role for composite roles which support overloading
 
@@ -18,11 +18,13 @@ use namespace::autoclean;
 
 around apply_params => sub {
     my ($next, $self, @args) = @_;
-    return Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class                           => $self->$next(@args),
-        application_to_class_class_roles    => [ ToClass    ],
-        application_to_role_class_roles     => [ ToRole     ],
-        application_to_instance_class_roles => [ ToInstance ],
+    return Moose::Util::MetaRole::apply_metaroles(
+        for            => $self->$next(@args),
+        role_metaroles => {
+            application_to_class    => [ToClass],
+            application_to_role     => [ToRole],
+            application_to_instance => [ToInstance],
+        },
     );
 };
 
